#' Helper functions
#'
#' A collection of handy, helper functions
#'
#' @import ggplot2
#' @keywords internal
"_PACKAGE"
